#!/usr/bin/python

import GeoIP

gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPRegion.dat",GeoIP.GEOIP_STANDARD)

gir = gi.region_by_name("www.google.com")
if gir != None:
            print gir['country_code']
            print gir['region']

gir = gi.region_by_addr("24.24.24.24")
if gir != None:
            print gir['country_code']
            print gir['region']



#!/usr/bin/python

import GeoIP

gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPOrg.dat",GeoIP.GEOIP_STANDARD)

print gi.org_by_name("yahoo.com")
print gi.org_by_name("www.government.de")
print gi.org_by_addr("203.195.93.0")



from distutils.core import setup, Extension

module1 = Extension('GeoIP',
	libraries = ['GeoIP'],
	sources = ['py_GeoIP.c'],
	library_dirs = ['/usr/local/lib'],
	include_dirs = ['/usr/local/include'])

setup (name = 'GeoIP-Python',
	version = '1.2.1',
	description = 'This is a python wrapper to GeoIP',
	ext_modules = [module1])



#!/usr/bin/python

import GeoIP

#gi = GeoIP.new(GeoIP.GEOIP_STANDARD)
gi = GeoIP.new(GeoIP.GEOIP_MEMORY_CACHE)
#gi = GeoIP.open("/usr/local/share/GeoIP/GeoIP.data",GeoIP.GEOIP_STANDARD)

print gi.country_code_by_name("yahoo.com")
print gi.country_name_by_name("www.government.de")
print gi.country_code_by_addr("203.195.93.0")
print gi.country_name_by_addr("203.195.93.0")
